
declare namespace lrts {

    export namespace logger {

        export interface LoggerHandler {

            (prefix: string, format: string, data: any): void;
        }

        export interface LoggerHandlerConfig {

            "prefix": string;

            "format": string;

            "handler": LoggerHandler;
        }

        export interface Logger {

            /**
             * Edit the prefix of log text for specific rule
             */
            setPrefix(name: string, text: string): void;

            /**
             * Get the prefix of log text for specific rule
             */
            getPrefix(name: string): string;

            /**
             * Create a new rule of format text, with Date prefix.
             */
            addDateFormatLog(name: string, format: string, prefix?: string): void;

            /**
             * Create a new rule of raw text, with Date prefix.
             */
            addDateTextLog(name: string, prefix?: string): void;

            /**
             * Create a new rule of raw text.
             */
            addTextLog(name: string, prefix?: string): void;

            /**
             * Create a new rule of format text.
             */
            addFormatLog(name: string, format: string, prefix?: string): void;

            /**
             * Create a new custom rule.
             */
            addCustomLog(name: string, handler: LoggerHandler, format: string, prefix?: string): void;

            /**
             * Write log
             */
            log(name: string, data: any): void;

        }
    }
}
