/// <reference path="../../lrt.d.ts" />
"use strict";
/**
 * ConsoleLogger
 */
var ConsoleLogger = (function () {
    function ConsoleLogger() {
        this.handlers = {
            ".date-simple": {
                "prefix": "",
                "format": "",
                "handler": function (prefix, format, data) {
                    console.log((new Date()).getSimpleDate() + " - " + prefix + data);
                }
            }
        };
    }
    ConsoleLogger.prototype.setPrefix = function (name, text) {
        this.handlers[name].prefix = text;
    };
    ConsoleLogger.prototype.getPrefix = function (name) {
        return this.handlers[name].prefix;
    };
    ConsoleLogger.prototype.dateTextLogger = function (prefix, format, data) {
        console.log(prefix + data);
    };
    ConsoleLogger.prototype.dateLogger = function (prefix, format, data) {
        console.log(prefix + data);
    };
    ConsoleLogger.prototype.addDateFormatLog = function (name, format, prefix) {
        this.handlers[name] = {
            "prefix": prefix ? prefix : "",
            "format": format ? format : "",
            "handler": function (prefix, format, data) {
                console.log((new Date()).getSimpleDate() + " - " + prefix + format.format(data));
            }
        };
    };
    ConsoleLogger.prototype.addDateTextLog = function (name, prefix) {
        this.handlers[name] = {
            "prefix": prefix ? prefix : "",
            "format": "",
            "handler": function (prefix, format, data) {
                console.log((new Date()).getSimpleDate() + " - " + prefix + data);
            }
        };
    };
    ConsoleLogger.prototype.addTextLog = function (name, prefix) {
        this.handlers[name] = {
            "prefix": prefix ? prefix : "",
            "format": "",
            "handler": function (prefix, format, data) {
                console.log(prefix + data);
            }
        };
    };
    ConsoleLogger.prototype.addFormatLog = function (name, format, prefix) {
        this.handlers[name] = {
            "prefix": prefix ? prefix : "",
            "format": format ? format : "",
            "handler": function (prefix, format, data) {
                console.log(prefix + format.format(data));
            }
        };
    };
    ConsoleLogger.prototype.addCustomLog = function (name, handler, format, prefix) {
        this.handlers[name] = {
            "prefix": prefix ? prefix : "",
            "format": format ? format : "",
            "handler": handler
        };
    };
    ConsoleLogger.prototype.log = function (name, data) {
        var config = this.handlers[name];
        if (!config) {
            return;
        }
        config.handler(config.prefix, config.format, data);
    };
    return ConsoleLogger;
}());
module.exports = ConsoleLogger;
//# sourceMappingURL=ConsoleLogger.js.map