/// <reference path="../../lrt.d.ts" />

/**
 * ConsoleLogger
 */
class ConsoleLogger implements lrts.logger.Logger {

    protected handlers: { [key: string]: lrts.logger.LoggerHandlerConfig; };

    constructor() {

        this.handlers = {

            ".date-simple": {

                "prefix": "",

                "format": "",

                "handler": function(prefix: string, format: string, data: any): void {

                    console.log((new Date()).getSimpleDate() + " - " + prefix + data);

                }
            }
        };
    }

    public setPrefix(name: string, text: string): void {

        this.handlers[name].prefix = text;

    }

    public getPrefix(name: string): string {

        return this.handlers[name].prefix;

    }

    protected dateTextLogger(prefix: string, format: string, data: any): void {

        console.log(prefix + data);

    }

    protected dateLogger(prefix: string, format: string, data: any): void {

        console.log(prefix + data);

    }

    public addDateFormatLog(name: string, format: string, prefix?: string): void {

        this.handlers[name] = {

            "prefix": prefix ? prefix : "",

            "format": format ? format : "",

            "handler": function(prefix: string, format: string, data: any): void {

                console.log((new Date()).getSimpleDate() + " - " + prefix + format.format(data));

            }
        };

    }

    public addDateTextLog(name: string,  prefix?: string): void {

        this.handlers[name] = {

            "prefix": prefix ? prefix : "",

            "format": "",

            "handler": function(prefix: string, format: string, data: any): void {

                console.log((new Date()).getSimpleDate() + " - " + prefix + data);

            }
        };

    }

    public addTextLog(name: string, prefix?: string): void {

        this.handlers[name] = {

            "prefix": prefix ? prefix : "",

            "format": "",

            "handler": function(prefix: string, format: string, data: any): void {

                console.log(prefix + data);

            }
        };

    }

    public addFormatLog(name: string, format: string, prefix?: string): void {

        this.handlers[name] = {

            "prefix": prefix ? prefix : "",

            "format": format ? format : "",

            "handler": function(prefix: string, format: string, data: any): void {

                console.log(prefix + format.format(data));

            }
        };

    }

    public addCustomLog(name: string, handler: lrts.logger.LoggerHandler, format: string, prefix?: string): void {

        this.handlers[name] = {

            "prefix": prefix ? prefix : "",

            "format": format ? format : "",

            "handler": handler
        };

    }

    public log(name: string, data: any): void {

        let config: lrts.logger.LoggerHandlerConfig = this.handlers[name];

        if (!config) {

            return;
        }

        config.handler(config.prefix, config.format, data);

    }

}

export = ConsoleLogger;
